# bottomUpAnalysis_example.R
# An example application of bottom analysis to the sample dataset
# this file identifies critical threshold of precipitation (P) change for a 25% reduction in P-ET
# at a 10% increase in potential evaporatranspiration (PE)

# clean up
rm(list=ls())
graphics.off()

# install required packages/ files
library(akima)
source('budyko_m1.R')

# load the Fu's fits for each unit, output from omega_fit_regional.R file
load('omegafit.RData')

##################################### Vulnerability calculation ##############################
# read in some data 
aridityind          <- output$aridityind
evapratio           <- output$evapratio
precip              <- output$precip
omegafit            <- output$omegafit
numunits            <- length(aridityind)
# set the range of P change and PE change to sample from 
prange              <- c(0.5, 1.8)
perange             <- c(1.0, 1.2)
# generate the scenarios
nrand               <- 100
pchangeall          <- seq(prange[1],  prange[2],  (prange[2]-prange[1])/(nrand-1))
pechangeall         <- seq(perange[1], perange[2], (perange[2]-perange[1])/(nrand-1))

# define variable to store vulnerability estimates
unitwisevul         <- array(NA, c(nrand, nrand, numunits))

# estimate P-ET for each climate scenario
for (i in 1:nrand) {
  for (j in 1:nrand) {
    oldunitarid <- aridityind
    newunitarid <- oldunitarid*pechangeall[j]/pchangeall[i]
    # for each unit, estimate the 
    for (units in 1:numunits){    
      if (is.nan(oldunitarid[units])==FALSE) {
        # identify the group to which the district belongs
        omegatouse <- omegafit[units]

        # now make the prediction of evapratio using omega value for old and new climate
        oldevapratio          <- budyko_m1(oldunitarid[units], omegatouse)
        newevapratio          <- budyko_m1(newunitarid[units], omegatouse)
        newprecip             <- precip*pchangeall[i]
        
        # estimate W = P - AE = P - P*(AE/P) for each climate
        oldmeanWA              <-  precip[units]      - precip[units]*oldevapratio
        newmeanWA              <-  newprecip[units]   - newprecip[units]*newevapratio
        
        # estimate the difference    
        tempvul                     <-  (newmeanWA-oldmeanWA)/oldmeanWA  
        unitwisevul[i,j,units]      <-  tempvul
        
        # clean up
        rm(omegatouse, oldevapratio, newevapratio, tempvul)
      }
    }
  }
  print(i)
}

# identify the precipitation change causing 25% reduction in water availability at delta_PE = 10%
del_PE         <- 1.1   # setting PE change to 10%, expressed in multiplier
del_WA         <- -0.25 # required threshold of vulnerability, expressed in fraction
totaln         <- nrand*nrand
interpxval     <- rep(NA, totaln)
interpzval     <- rep(NA, totaln)
interpPval     <- rep(NA, numunits)
for (i in 1:totaln) {  
  assignp      <- i - (i%/%nrand)*nrand
  assignpe     <- (i+nrand)%/%nrand 
  if (assignp == 0)   { assignp = nrand }
  if (i%%nrand == 0)  { assignpe = assignpe -1 }
  interpxval[i] <- pechangeall[assignpe] 
  interpzval[i] <- pchangeall[assignp]
}
for (units in 1:numunits){ 
  interpyval        <- as.vector(unitwisevul[,,units])
  if (length(which(is.na(interpyval)==TRUE)) > 1) {
    interpPval[units] <- NA 
  } else {
    temp              <- interp(interpxval, interpyval, interpzval, xo = del_PE, yo = del_WA )
    interpPval[units] <- temp$z
    rm(temp)
  }    
}
# interPval is the variable that contains values for the precipitation threshold for each unit
# (1-interpPval)*100 is the reduction in precipitation that will cause a 25% reduction in water availability
precip_thres    <- (1-interpPval)*100
bottomup_out    <- list(interpPval= interpPval, precip_thres, unitwisevul = unitwisevul)
############### save the data for use in plotting in 'IndiaBottomUp.R' #############
save(bottomup_out,  file = 'bottomup_out_example.RData')